@@ -1,5 +1,5 @@
 /*
-Language: LiveCode server and revIgniter
+Language: LiveCode
 Author: Ralf Bitter <rabit@revigniter.com>
 Description: Language definition for LiveCode server accounting for revIgniter (a web application framework) characteristics.
 Version: 1.0a
