@@ -5,7 +5,6 @@ Contributors: Eugene Nizhibitsky <nizhibitsky@ya.ru>
 */
 
 function(hljs) {
-
   var COMMON_CONTAINS = [
     hljs.C_NUMBER_MODE,
     {
@@ -66,9 +65,13 @@ function(hljs) {
       },
       {
         className: 'cell',
-        begin: '\\{', end: '\\}\'*[\\.\']*',
+        begin: '\\{',
         contains: COMMON_CONTAINS,
-        illegal: /:/
+        illegal: /:/,
+        variants: [
+          {end: /\}'[\.']*/},
+          {end: /\}/, relevance: 0}
+        ]
       },
       {
         className: 'comment',
