@@ -6,6 +6,7 @@ Description: OCaml language definition.
 */
 function(hljs) {
   return {
+    aliases: ['ml'],
     keywords: {
       keyword:
         'and as assert asr begin class constraint do done downto else end ' +
@@ -15,7 +16,7 @@ function(hljs) {
         'then to true try type val virtual when while with parser value',
       built_in:
         'bool char float int list unit array exn option int32 int64 nativeint ' +
-        'format4 format6 lazy_t in_channel out_channel string',
+        'format4 format6 lazy_t in_channel out_channel string'
     },
     illegal: /\/\//,
     contains: [
@@ -30,7 +31,7 @@ function(hljs) {
       },
       {
         className: 'class',
-        beginKeywords: 'type', end: '\\(|=|$',
+        beginKeywords: 'type', end: '\\(|=|$', excludeEnd: true,
         contains: [
           hljs.UNDERSCORE_TITLE_MODE
         ]
